@@ -23,6 +23,8 @@ def main(main_args=None):
     my_parser.add_argument('--update', default=False, action=argparse.BooleanOptionalAction, help="Create PR for updating dependencies.")
     my_parser.add_argument('--getgitconfig', default=False, action=argparse.BooleanOptionalAction, help="Get Your Github Configurations")
     my_parser.add_argument("--setgitconfig",nargs=2,type=str, help="Set your git username and password")
+    my_parser.add_argument("--createcsv", default=False, action=argparse.BooleanOptionalAction, help="Create csv of all the repositories whose language is JavaScript")
+    my_parser.add_argument("--org", nargs=1, type=str, help="Enter name of the organization you want to scan for javascript repositories")
 
     args = my_parser.parse_args(main_args)
 
@@ -188,4 +190,33 @@ def main(main_args=None):
             writer.writerow(result_header)
 
             # write the data
-            writer.writerows(result_rows)
\ No newline at end of file
+            writer.writerows(result_rows)
+
+    if args.createcsv:
+        createcsv_header = ["name","repo"]
+        createcsv_result = []
+
+        if args.org:
+            org_name = args.org[0]
+            url = "https://api.github.com/orgs/" + org_name + "/repos"
+        else:
+            url = "https://api.github.com/users/" + variables["github_username"] + "/repos"
+
+        req = requests.get(url,headers={"Authorization": "Basic " + base64.b64encode(("%s:%s" % (variables["github_username"], variables["github_password"])).encode('utf-8')).decode('utf-8')})
+        req = req.json()
+
+        for i in req:
+            if i["language"] == "JavaScript":
+                createcsv_result.append([i["name"], i["html_url"]])
+
+        if len(createcsv_result) != 0:
+            with open(os.path.expanduser("~/repositories.csv"), 'w', encoding='UTF8', newline='') as f:
+                writer = csv.writer(f)
+
+                # write the header
+                writer.writerow(createcsv_header)
+
+                # write the data
+                writer.writerows(createcsv_result)
+
+                print("repositories.csv created in your home directory.")
\ No newline at end of file
